; common_settings.g
; This file contains settings which do not change between system configurations
; Version 3.1.1R0.1

; Main machine settings
M111 S0                                         ; Debugging off
G21                                             ; Work in millimetres
G90                                             ; Send absolute coordinates
M82                                             ; Send absolute extruder moves

; PanelDue setup
M575 P1 B57600 S1                               ; set serial port to 57600 baud, paneldue mode

; Bed probe initial setup
M950 S7 C"!exp.heater_7"                        ; create servo 7 output on expansion heater 7
M558 P9 C"e1_stop" H3 B1 F120 T6000             ; touch probe connected to e1_stop
G31 P100 X0 Y0 Z0.00                            ; Set Z probe trigger value, offset and trigger height
M376 H20                                        ; Set bed compensation taper height to 20mm (bed compensation motion will flatten from 0-20mm)

; Bed thermal sensor and heater setup
M308 S0 P"bed_temp" Y"thermistor" T47500 B3988  ; Bind bed_temp therm input to sensor 0, + therm settings
M950 H0 C"bed_heat" T0 Q10                      ; Heater 0 uses bed_heat pin, temp sensor 0, 10Hz;
M140 H0                                         ; Assign Heater 0 as bed
M143 H0 S150                                    ; Max temp of 150C on bed heater
M301 H0 B1                                      ; Use bang-bang on bed heater

; Home switch setup
M574 X1 S1 P"!x_stop"                           ; X at min travel, active low
M574 Y1 S1 P"!y_stop"                           ; Y at min travel, active low
M574 Z1 S1 P"!z_stop"                           ; Z at min travel, active low

; Filament sensor switch setup
M950 J0 C"!^e0_stop"                            ; input 0 uses inverted signal, active LOW
M581 P0 T2 S1 R1                                ; Trigger 2 connected to input 0, activates on inactive-> active transition, only while SD card print is enabled

; Drive setup
M569 P0 R-1                                     ; Drive 0 disabled
M569 P1 R-1                                     ; Drive 1 disabled
M569 P2 R-1                                     ; Drive 2 disabled
M569 P3 S1                                      ; left extruder goes forwards
M569 P4 S1                                      ; right extruder goes forwards
M569 P5 T2                                      ; 2 microsecond minimum step pulse width for x-axis
M569 P6 T2                                      ; 2 microsecond minimum step pulse width for y-axis
M569 P7 T2                                      ; 2 microsecond minimum step pulse width for z-axis
M584 X5 Y6 Z7 E3:4                              ; Apply custom drive mapping (X=Drive5, Y=Drive6, Z=Drive7, E3=Extruder0, E4-Extruder1 )
M350 E16:16 I1                                  ; Configure microstepping with interpolation for extruder drives
M92 X120 Y120 Z2000                             ; Set steps per mm
M566 X225 Y225 Z12                              ; Set maximum instantaneous speed changes (mm/min)
M203 X12000 Y12000 Z1000                        ; Set maximum speeds (mm/min)
M201 X1000 Y1000 Z250                           ; Set accelerations (mm/s^2)
M906 X0 Y0 Z0 I30                               ; Set motor currents (mA) and motor idle factor in percent
M84 S30                                         ; Set idle timeout

; Fan setup
M950 F0 C"fan0" Q500                            ; create fan0 output, pwm 500hz
M950 F1 C"fan1" Q500                            ; create fan1 output, pwm 500hz
M950 F2 C"fan2" Q500                            ; create fan2 output, pwm 500hz

M106 P0 S0 B0.2 H-1 C"Print cooling fan"        ; fan0 is print cooling 
M106 P1 S0 B0.2 H-1	                            ; fan 1 (print cooling fan spare output)
M106 P2 S0 H0 T70:70                            ; fan 2 (bed warning LED), illuminates when bet is >= 70C